[![Lint](https://github.com/Quasars/orange-snom/actions/workflows/lint.yml/badge.svg)](https://github.com/Quasars/orange-snom/actions/workflows/lint.yml)
[![Test](https://github.com/Quasars/orange-snom/actions/workflows/test.yml/badge.svg)](https://github.com/Quasars/orange-snom/actions/workflows/test.yml)
[![Release](https://github.com/Quasars/orange-snom/actions/workflows/release.yml/badge.svg)](https://github.com/Quasars/orange-snom/actions/workflows/release.yml)

Orange toolbox for SNOM
=======================

This is an add-on for [Orange3](http://orange.biolab.si) for scanning near-field optical microscopy.
